@@ -19,7 +19,18 @@ Handle http links.
 """
 
 import requests
-from cStringIO import StringIO
+# The validity of SSL certs is ignored to be able
+# the check the URL and recurse into it.
+# The warning about invalid SSL certs is given to the
+# user instead.
+import warnings
+warnings.simplefilter('ignore', requests.packages.urllib3.exceptions.InsecureRequestWarning)
+
+try:
+    from cStringIO import StringIO
+except ImportError:
+    # Python 3
+    from io import StringIO
 
 from .. import (log, LOG_CHECK, strformat, mimeutil,
     url as urlutil, LinkCheckerError, httputil)
@@ -48,6 +59,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         super(HttpUrl, self).reset()
         # initialize check data
+        # server headers
         self.headers = {}
         self.auth = None
         self.ssl_cipher = None
@@ -63,7 +75,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         @return: True if access is granted, otherwise False
         @rtype: bool
         """
-        return self.aggregate.robots_txt.allows_url(self)
+        return not self.aggregate.config['robotstxt'] or self.aggregate.robots_txt.allows_url(self)
 
     def content_allows_robots (self):
         """
@@ -166,7 +178,8 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
 
     def _send_request(self, request, **kwargs):
         """Send GET request."""
-        log.debug(LOG_CHECK, "Send request with %s", kwargs)
+        log.debug(LOG_CHECK, "Send request %s with %s", request, kwargs)
+        log.debug(LOG_CHECK, "Request headers %s", request.headers)
         self.url_connection = self.session.send(request, **kwargs)
         self.headers = self.url_connection.headers
         self._add_ssl_info()
@@ -181,6 +194,10 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """Get raw SSL socket."""
         assert self.scheme == u"https", self
         raw_connection = self.url_connection.raw._connection
+        if not raw_connection:
+            # this happens with newer requests versions:
+            # https://github.com/linkcheck/linkchecker/issues/76
+            return None
         if raw_connection.sock is None:
             # sometimes the socket is not yet connected
             # see https://github.com/kennethreitz/requests/issues/1966
@@ -191,7 +208,10 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """Add SSL cipher info."""
         if self.scheme == u'https':
             sock = self._get_ssl_sock()
-            if hasattr(sock, 'cipher'):
+            if not sock:
+                log.debug(LOG_CHECK, "cannot extract SSL certificate from connection")
+                self.ssl_cert = None
+            elif hasattr(sock, 'cipher'):
                 self.ssl_cert = sock.getpeercert()
             else:
                 # using pyopenssl
