@@ -25,7 +25,8 @@ import traceback
 try:
     from cStringIO import StringIO
 except ImportError:
-    from StringIO import StringIO
+    # Python 3
+    from io import StringIO
 
 # memory leak debugging
 #import gc
@@ -53,7 +54,7 @@ def _stack_format (stack):
                 try:
                     s.write(repr(value))
                     s.write(os.linesep)
-                except StandardError:
+                except Exception:
                     s.write("error in repr() call%s" % os.linesep)
     return s.getvalue()
 
