@@ -18,11 +18,17 @@
 Functions for parsing and matching URL strings.
 """
 
-import re
 import os
-import urlparse
-import urllib
+import re
+try:  # Python 3
+    from urllib import parse
+    from urllib import parse as urlparse
+except ImportError:  # Python 2
+    import urllib as parse
+    import urlparse
+
 import requests
+
 from . import log, LOG_CHECK
 
 for scheme in ('ldap', 'irc'):
@@ -158,9 +164,9 @@ def parse_qsl (qs, keep_blank_values=0, strict_parsing=0):
             else:
                 continue
         if nv[1] or keep_blank_values:
-            name = urllib.unquote(nv[0].replace('+', ' '))
+            name = parse.unquote(nv[0].replace('+', ' '))
             if nv[1]:
-                value = urllib.unquote(nv[1].replace('+', ' '))
+                value = parse.unquote(nv[1].replace('+', ' '))
             else:
                 value = nv[1]
             r.append((name, value, sep))
@@ -185,12 +191,12 @@ def idna_encode (host):
 def url_fix_host (urlparts):
     """Unquote and fix hostname. Returns is_idn."""
     if not urlparts[1]:
-        urlparts[2] = urllib.unquote(urlparts[2])
+        urlparts[2] = parse.unquote(urlparts[2])
         return False
-    userpass, netloc = urllib.splituser(urlparts[1])
+    userpass, netloc = parse.splituser(urlparts[1])
     if userpass:
-        userpass = urllib.unquote(userpass)
-    netloc, is_idn = idna_encode(urllib.unquote(netloc).lower())
+        userpass = parse.unquote(userpass)
+    netloc, is_idn = idna_encode(parse.unquote(netloc).lower())
     # a leading backslash in path causes urlsplit() to add the
     # path components up to the first slash to host
     # try to find this case...
@@ -201,7 +207,7 @@ def url_fix_host (urlparts):
         if not urlparts[2] or urlparts[2] == '/':
             urlparts[2] = comps
         else:
-            urlparts[2] = "%s%s" % (comps, urllib.unquote(urlparts[2]))
+            urlparts[2] = "%s%s" % (comps, parse.unquote(urlparts[2]))
         netloc = netloc[:i]
     else:
         # a leading ? in path causes urlsplit() to add the query to the
@@ -210,7 +216,7 @@ def url_fix_host (urlparts):
         if i != -1:
             netloc, urlparts[3] = netloc.split('?', 1)
         # path
-        urlparts[2] = urllib.unquote(urlparts[2])
+        urlparts[2] = parse.unquote(urlparts[2])
     if userpass:
         # append AT for easy concatenation
         userpass += "@"
@@ -242,6 +248,13 @@ def url_fix_mailto_urlsplit (urlparts):
     if "?" in urlparts[2]:
         urlparts[2], urlparts[3] = urlparts[2].split('?', 1)
 
+# wayback urls include in the path http[s]://. By default the
+# tidying mechanism in linkchecker encodes the : and deletes the second slash
+# This function reverses these corrections. This function expects only the
+# path section of the URL as input.
+wayback_regex = re.compile(r'(https?)(\%3A/|:/)')
+def url_fix_wayback_query(path):
+    return wayback_regex.sub(r'\1://', path)
 
 def url_parse_query (query, encoding=None):
     """Parse and re-join the given CGI query."""
@@ -255,7 +268,7 @@ def url_parse_query (query, encoding=None):
         query, rest = query.rsplit('?', 1)
         append = '?'+url_parse_query(rest)+append
     l = []
-    for k, v, sep in parse_qsl(query, True):
+    for k, v, sep in parse_qsl(query, keep_blank_values=True):
         k = url_quote_part(k, '/-:,;')
         if v:
             v = url_quote_part(v, '/-:,;')
@@ -300,7 +313,7 @@ def url_norm (url, encoding=None):
         encode_unicode = False
     urlparts = list(urlparse.urlsplit(url))
     # scheme
-    urlparts[0] = urllib.unquote(urlparts[0]).lower()
+    urlparts[0] = parse.unquote(urlparts[0]).lower()
     # mailto: urlsplit is broken
     if urlparts[0] == 'mailto':
         url_fix_mailto_urlsplit(urlparts)
@@ -320,12 +333,14 @@ def url_norm (url, encoding=None):
             # fix redundant path parts
             urlparts[2] = collapse_segments(urlparts[2])
     # anchor
-    urlparts[4] = urllib.unquote(urlparts[4])
+    urlparts[4] = parse.unquote(urlparts[4])
     # quote parts again
     urlparts[0] = url_quote_part(urlparts[0], encoding=encoding) # scheme
     urlparts[1] = url_quote_part(urlparts[1], safechars='@:', encoding=encoding) # host
     urlparts[2] = url_quote_part(urlparts[2], safechars=_nopathquote_chars, encoding=encoding) # path
-    urlparts[4] = url_quote_part(urlparts[4], encoding=encoding) # anchor
+    if not urlparts[0].startswith("feed"):
+        urlparts[2] = url_fix_wayback_query(urlparts[2]) # unencode colon in http[s]:// in wayback path
+    urlparts[4] = url_quote_part(urlparts[4], safechars="!$&'()*+,-./;=?@_~", encoding=encoding) # anchor
     res = urlunsplit(urlparts)
     if url.endswith('#') and not urlparts[4]:
         # re-append trailing empty fragment
@@ -373,7 +388,7 @@ def collapse_segments (path):
     return path
 
 
-url_is_absolute = re.compile("^[a-z]+:", re.I).match
+url_is_absolute = re.compile(r"^[-\.a-z]+:", re.I).match
 
 
 def url_quote (url):
@@ -405,11 +420,11 @@ def url_quote_part (s, safechars='/', encoding=None):
         if encoding is None:
             encoding = url_encoding
         s = s.encode(encoding, 'ignore')
-    return urllib.quote(s, safechars)
+    return parse.quote(s, safechars)
 
 def document_quote (document):
     """Quote given document."""
-    doc, query = urllib.splitquery(document)
+    doc, query = parse.splitquery(document)
     doc = url_quote_part(doc, '/=,')
     if query:
         return "%s?%s" % (doc, query)
@@ -460,8 +475,8 @@ def url_split (url):
     hostname is always lowercased.
     Precondition: url is syntactically correct URI (eg has no whitespace)
     """
-    scheme, netloc = urllib.splittype(url)
-    host, document = urllib.splithost(netloc)
+    scheme, netloc = parse.splittype(url)
+    host, document = parse.splithost(netloc)
     port = default_ports.get(scheme, 0)
     if host:
         host = host.lower()
